@@ -11,7 +11,7 @@ use Carp;
 
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.3';
 
 # ----------------------------------------------------------------------------
 # Private methods
@@ -118,9 +118,9 @@ callbacks.
   File::DirCompare->compare($dir1, $dir2, sub {
     my ($a, $b) = @_;
     if (! $b) {
-      printf "Only in $dir1: %s\n", basename($a);
+      printf "Only in %s: %s\n", dirname($a), basename($a);
     } elsif (! $a) {
-      printf "Only in $dir2: %s\n", basename($b);
+      printf "Only in %s: %s\n", dirname($b), basename($b);
     } else {
       print "Files $a and $b differ\n";
     }
@@ -242,7 +242,7 @@ with whitespace.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006 by Gavin Carr.
+Copyright 2006-2007 by Gavin Carr.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
